import { ThemeProvider } from '@/components/theme-provider'
import { TooltipProvider } from '@/components/ui/tooltip'
import { cn } from '@/lib/utils'
import type { Metadata } from 'next'
import { Inter as FontSans } from 'next/font/google'
import { getPayload } from 'payload'
import configPromise from '@payload-config'
import Navbar from '@/globals/Nav/component'

const fontSans = FontSans({
  subsets: ['latin'],
  variable: '--font-sans',
})

const payload = await getPayload({ config: configPromise })

const metaProps = await payload.findGlobal({
  slug: 'meta',
})

const navProps = await payload.findGlobal({
  slug: 'nav',
})

export const metadata: Metadata = {
  metadataBase: new URL(metaProps.url || ''),
  title: {
    default: metaProps.name || '',
    template: `%s | ${metaProps.name}`,
  },
  description: metaProps.description,
  openGraph: {
    title: `${metaProps.name}`,
    description: metaProps.description || '',
    url: metaProps.url || '',
    siteName: `${metaProps.name}`,
    locale: 'en_US',
    type: 'website',
  },
  robots: {
    index: true,
    follow: true,
    googleBot: {
      index: true,
      follow: true,
      'max-video-preview': -1,
      'max-image-preview': 'large',
      'max-snippet': -1,
    },
  },
  twitter: {
    title: `${metaProps.name}`,
    card: 'summary_large_image',
  },
  verification: {
    google: `${metaProps.googleVerification}`,
    yandex: '',
  },
}

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode
}>) {
  return (
    <html lang="en" suppressHydrationWarning>
      <body
        className={cn(
          'min-h-screen bg-background font-sans antialiased max-w-2xl mx-auto py-12 sm:py-24 px-6',
          fontSans.variable,
        )}
      >
        <ThemeProvider attribute="class" defaultTheme="light">
          <TooltipProvider delayDuration={0}>
            <main>{children}</main>
            <Navbar {...navProps} />
          </TooltipProvider>
        </ThemeProvider>
      </body>
    </html>
  )
}
