import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar'
import BlurFade from '@/components/ui/blur-fade'
import BlurFadeText from '@/components/ui/blur-fade-text'
import type { Media, ProfileBriefBlock as ProfileBriefProps } from '@/payload-types'

const BLUR_FADE_DELAY = 0.04
const INITITALS = 'YS'

type Props = {
  className?: string
} & ProfileBriefProps
export const ProfileBrief = (props: Props) => {
  const avatar = (props.avatar as Media) || undefined
  return (
    <section id="hero">
      <div className="mx-auto w-full max-w-2xl space-y-8">
        <div className="gap-2 flex justify-between">
          <div className="flex-col flex flex-1 space-y-1.5">
            <BlurFadeText
              delay={BLUR_FADE_DELAY}
              className="text-3xl font-bold tracking-tighter sm:text-5xl xl:text-6xl/none"
              yOffset={8}
              text={props.heading || ''}
            />
            <BlurFadeText
              className="max-w-[600px] md:text-xl"
              delay={BLUR_FADE_DELAY}
              text={props.subheading || ''}
            />
          </div>
          <BlurFade delay={BLUR_FADE_DELAY}>
            <Avatar className="size-28 border">
              <AvatarImage alt={avatar?.alt || ''} src={avatar?.url || ''} />
              <AvatarFallback>{INITITALS}</AvatarFallback>
            </Avatar>
          </BlurFade>
        </div>
      </div>
    </section>
  )
}
