import { ProjectCard } from '@/components/project-card'
import BlurFade from '@/components/ui/blur-fade'
import { BadgeListBlock, Media, ShowcaseBlock as ShowcaseProps } from '@/payload-types'
import { ShowcaseCardBlock as ShowcaseCardProps } from '@/payload-types'
import { DefaultTypedEditorState } from '@payloadcms/richtext-lexical'

const BLUR_FADE_DELAY = 0.04

type CardProps = { className?: string; index: number } & ShowcaseCardProps
export const ShowcaseCard = (props: CardProps) => {
  const realtedImage = props.image as Media | undefined
  const realtedVideo = props.video as Media | undefined
  const description = props.description as DefaultTypedEditorState | undefined
  const tags = (props.tags as BadgeListBlock[]) || []
  const links = (props.links as BadgeListBlock[]) || []
  return (
    <BlurFade delay={BLUR_FADE_DELAY * 12 + props.index * 0.05}>
      <ProjectCard
        href={props.mainLink || ''}
        title={props.title || ''}
        description={description}
        dates={props.unstructuredDate || ''}
        tags={tags}
        image={realtedImage}
        video={realtedVideo}
        links={links}
      />
    </BlurFade>
  )
}

type ShowcaseComponentProps = { className: string } & ShowcaseProps
export const Showcase = (props: ShowcaseComponentProps) => {
  return (
    <section id={props.blockName || ''}>
      <div className="space-y-12 w-full py-12">
        <BlurFade delay={BLUR_FADE_DELAY * 11}>
          <div className="flex flex-col items-center justify-center space-y-4 text-center">
            <div className="space-y-2">
              <h2 className="inline-block rounded-lg bg-foreground text-background px-3 py-1 text-sm">
                {props.listName}
              </h2>
              <h3 className="text-3xl font-bold tracking-tighter sm:text-5xl">{props.heading}</h3>
              <p className="text-muted-foreground md:text-xl/relaxed lg:text-base/relaxed xl:text-xl/relaxed">
                {props.subheading}
              </p>
            </div>
          </div>
        </BlurFade>
        <div className="grid grid-cols-1 gap-3 sm:grid-cols-2 max-w-[800px] mx-auto">
          {props.lineItems?.map((item, i) => <ShowcaseCard key={item.title} index={i} {...item} />)}
        </div>
      </div>
    </section>
  )
}
