import { s3Storage } from '@payloadcms/storage-s3'
import { postgresAdapter } from '@payloadcms/db-postgres'
import { payloadCloudPlugin } from '@payloadcms/payload-cloud'
import path from 'path'
import { buildConfig } from 'payload'
import { fileURLToPath } from 'url'
import sharp from 'sharp'

import { Users } from './collections/Users'
import { Media } from './collections/Media'
import { Pages } from './collections/Pages'
import { defaultLexical } from './fields/defaultLexical'
import { NavGlobal } from './globals/Nav/config'
import { MetaGlobal } from './globals/Meta/config'

const filename = fileURLToPath(import.meta.url)
const dirname = path.dirname(filename)

export default buildConfig({
  admin: {
    user: Users.slug,
    importMap: {
      baseDir: path.resolve(dirname),
    },
  },
  collections: [Users, Media, Pages],
  globals: [MetaGlobal, NavGlobal],
  editor: defaultLexical,
  secret: process.env.PAYLOAD_SECRET || '',
  typescript: {
    outputFile: path.resolve(dirname, 'payload-types.ts'),
  },
  db: postgresAdapter({
    pool: {
      connectionString: process.env.DATABASE_URI || '',
    },
  }),
  sharp,
  plugins: [
    payloadCloudPlugin(),
    s3Storage({
      collections: {
        media: true,
      },
      bucket: 'ysandler-work',
      config: {
        credentials: {
          accessKeyId: process.env.ACCESS_KEY_ID || '',
          secretAccessKey: process.env.SECRET_ACCESS_KEY || '',
        },
        region: 'us-east-1',
        endpoint: 'http://192.168.1.131:9000',
        forcePathStyle: true,
      }
    })
  ],
})
